## Summary

Brief description of the changes in this PR.

## Related Issues

- Closes #XXX (if applicable)
- Related to #XXX

## Changes Made

- Change 1
- Change 2
- Change 3

## Test Plan

Describe how you tested these changes:

- [ ] Unit tests added/updated
- [ ] Integration tests added/updated
- [ ] Manual testing performed

## Checklist

- [ ] Code follows project style guidelines
- [ ] Tests pass locally (`make test`)
- [ ] Linting passes (`make lint`)
- [ ] Documentation updated (if applicable)
- [ ] CHANGELOG.md updated (for user-facing changes)
- [ ] Commit messages follow conventional commit format
- [ ] DCO sign-off included (`git commit -s`)

## Screenshots (if applicable)

Add screenshots for UI changes.

## Additional Notes

Any additional context or notes for reviewers.
